@@ -16,15 +16,15 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 
-from google.api_core.client_options import ClientOptions
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import retry as retries
+from google.api_core.client_options import ClientOptions
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+import pkg_resources
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -33,14 +33,16 @@ except AttributeError:  # pragma: NO COVER
 
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
-from google.cloud.deploy_v1.services.cloud_deploy import pagers
-from google.cloud.deploy_v1.types import cloud_deploy
 from google.protobuf import empty_pb2  # type: ignore
 from google.protobuf import field_mask_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
-from .transports.base import CloudDeployTransport, DEFAULT_CLIENT_INFO
-from .transports.grpc_asyncio import CloudDeployGrpcAsyncIOTransport
+
+from google.cloud.deploy_v1.services.cloud_deploy import pagers
+from google.cloud.deploy_v1.types import cloud_deploy
+
 from .client import CloudDeployClient
+from .transports.base import DEFAULT_CLIENT_INFO, CloudDeployTransport
+from .transports.grpc_asyncio import CloudDeployGrpcAsyncIOTransport
 
 
 class CloudDeployAsyncClient:
@@ -64,6 +66,8 @@ class CloudDeployAsyncClient:
     parse_delivery_pipeline_path = staticmethod(
         CloudDeployClient.parse_delivery_pipeline_path
     )
+    membership_path = staticmethod(CloudDeployClient.membership_path)
+    parse_membership_path = staticmethod(CloudDeployClient.parse_membership_path)
     release_path = staticmethod(CloudDeployClient.release_path)
     parse_release_path = staticmethod(CloudDeployClient.parse_release_path)
     rollout_path = staticmethod(CloudDeployClient.rollout_path)
@@ -234,14 +238,13 @@ class CloudDeployAsyncClient:
         r"""Lists DeliveryPipelines in a given project and
         location.
 
-
         .. code-block:: python
 
             from google.cloud import deploy_v1
 
-            def sample_list_delivery_pipelines():
+            async def sample_list_delivery_pipelines():
                 # Create a client
-                client = deploy_v1.CloudDeployClient()
+                client = deploy_v1.CloudDeployAsyncClient()
 
                 # Initialize request argument(s)
                 request = deploy_v1.ListDeliveryPipelinesRequest(
@@ -252,7 +255,7 @@ class CloudDeployAsyncClient:
                 page_result = client.list_delivery_pipelines(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -322,12 +325,20 @@ class CloudDeployAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListDeliveryPipelinesAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -348,9 +359,9 @@ class CloudDeployAsyncClient:
 
             from google.cloud import deploy_v1
 
-            def sample_get_delivery_pipeline():
+            async def sample_get_delivery_pipeline():
                 # Create a client
-                client = deploy_v1.CloudDeployClient()
+                client = deploy_v1.CloudDeployAsyncClient()
 
                 # Initialize request argument(s)
                 request = deploy_v1.GetDeliveryPipelineRequest(
@@ -358,7 +369,7 @@ class CloudDeployAsyncClient:
                 )
 
                 # Make the request
-                response = client.get_delivery_pipeline(request=request)
+                response = await client.get_delivery_pipeline(request=request)
 
                 # Handle the response
                 print(response)
@@ -431,7 +442,12 @@ class CloudDeployAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -450,14 +466,13 @@ class CloudDeployAsyncClient:
         r"""Creates a new DeliveryPipeline in a given project and
         location.
 
-
         .. code-block:: python
 
             from google.cloud import deploy_v1
 
-            def sample_create_delivery_pipeline():
+            async def sample_create_delivery_pipeline():
                 # Create a client
-                client = deploy_v1.CloudDeployClient()
+                client = deploy_v1.CloudDeployAsyncClient()
 
                 # Initialize request argument(s)
                 request = deploy_v1.CreateDeliveryPipelineRequest(
@@ -470,7 +485,7 @@ class CloudDeployAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -552,7 +567,12 @@ class CloudDeployAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -581,9 +601,9 @@ class CloudDeployAsyncClient:
 
             from google.cloud import deploy_v1
 
-            def sample_update_delivery_pipeline():
+            async def sample_update_delivery_pipeline():
                 # Create a client
-                client = deploy_v1.CloudDeployClient()
+                client = deploy_v1.CloudDeployAsyncClient()
 
                 # Initialize request argument(s)
                 request = deploy_v1.UpdateDeliveryPipelineRequest(
@@ -594,7 +614,7 @@ class CloudDeployAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -675,7 +695,12 @@ class CloudDeployAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -703,9 +728,9 @@ class CloudDeployAsyncClient:
 
             from google.cloud import deploy_v1
 
-            def sample_delete_delivery_pipeline():
+            async def sample_delete_delivery_pipeline():
                 # Create a client
-                client = deploy_v1.CloudDeployClient()
+                client = deploy_v1.CloudDeployAsyncClient()
 
                 # Initialize request argument(s)
                 request = deploy_v1.DeleteDeliveryPipelineRequest(
@@ -717,7 +742,7 @@ class CloudDeployAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -755,9 +780,6 @@ class CloudDeployAsyncClient:
 
                       }
 
-                   The JSON representation for Empty is empty JSON
-                   object {}.
-
         """
         # Create or coerce a protobuf request object.
         # Quick check: If we got a request object, we should *not* have
@@ -791,7 +813,12 @@ class CloudDeployAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -819,9 +846,9 @@ class CloudDeployAsyncClient:
 
             from google.cloud import deploy_v1
 
-            def sample_list_targets():
+            async def sample_list_targets():
                 # Create a client
-                client = deploy_v1.CloudDeployClient()
+                client = deploy_v1.CloudDeployAsyncClient()
 
                 # Initialize request argument(s)
                 request = deploy_v1.ListTargetsRequest(
@@ -832,7 +859,7 @@ class CloudDeployAsyncClient:
                 page_result = client.list_targets(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -902,12 +929,20 @@ class CloudDeployAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListTargetsAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -928,9 +963,9 @@ class CloudDeployAsyncClient:
 
             from google.cloud import deploy_v1
 
-            def sample_get_target():
+            async def sample_get_target():
                 # Create a client
-                client = deploy_v1.CloudDeployClient()
+                client = deploy_v1.CloudDeployAsyncClient()
 
                 # Initialize request argument(s)
                 request = deploy_v1.GetTargetRequest(
@@ -938,7 +973,7 @@ class CloudDeployAsyncClient:
                 )
 
                 # Make the request
-                response = client.get_target(request=request)
+                response = await client.get_target(request=request)
 
                 # Handle the response
                 print(response)
@@ -1008,7 +1043,12 @@ class CloudDeployAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1030,9 +1070,9 @@ class CloudDeployAsyncClient:
 
             from google.cloud import deploy_v1
 
-            def sample_create_target():
+            async def sample_create_target():
                 # Create a client
-                client = deploy_v1.CloudDeployClient()
+                client = deploy_v1.CloudDeployAsyncClient()
 
                 # Initialize request argument(s)
                 request = deploy_v1.CreateTargetRequest(
@@ -1045,7 +1085,7 @@ class CloudDeployAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -1126,7 +1166,12 @@ class CloudDeployAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -1155,9 +1200,9 @@ class CloudDeployAsyncClient:
 
             from google.cloud import deploy_v1
 
-            def sample_update_target():
+            async def sample_update_target():
                 # Create a client
-                client = deploy_v1.CloudDeployClient()
+                client = deploy_v1.CloudDeployAsyncClient()
 
                 # Initialize request argument(s)
                 request = deploy_v1.UpdateTargetRequest(
@@ -1168,7 +1213,7 @@ class CloudDeployAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -1247,7 +1292,12 @@ class CloudDeployAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -1275,9 +1325,9 @@ class CloudDeployAsyncClient:
 
             from google.cloud import deploy_v1
 
-            def sample_delete_target():
+            async def sample_delete_target():
                 # Create a client
-                client = deploy_v1.CloudDeployClient()
+                client = deploy_v1.CloudDeployAsyncClient()
 
                 # Initialize request argument(s)
                 request = deploy_v1.DeleteTargetRequest(
@@ -1289,7 +1339,7 @@ class CloudDeployAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -1327,9 +1377,6 @@ class CloudDeployAsyncClient:
 
                       }
 
-                   The JSON representation for Empty is empty JSON
-                   object {}.
-
         """
         # Create or coerce a protobuf request object.
         # Quick check: If we got a request object, we should *not* have
@@ -1363,7 +1410,12 @@ class CloudDeployAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -1391,9 +1443,9 @@ class CloudDeployAsyncClient:
 
             from google.cloud import deploy_v1
 
-            def sample_list_releases():
+            async def sample_list_releases():
                 # Create a client
-                client = deploy_v1.CloudDeployClient()
+                client = deploy_v1.CloudDeployAsyncClient()
 
                 # Initialize request argument(s)
                 request = deploy_v1.ListReleasesRequest(
@@ -1404,7 +1456,7 @@ class CloudDeployAsyncClient:
                 page_result = client.list_releases(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -1473,12 +1525,20 @@ class CloudDeployAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListReleasesAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -1499,9 +1559,9 @@ class CloudDeployAsyncClient:
 
             from google.cloud import deploy_v1
 
-            def sample_get_release():
+            async def sample_get_release():
                 # Create a client
-                client = deploy_v1.CloudDeployClient()
+                client = deploy_v1.CloudDeployAsyncClient()
 
                 # Initialize request argument(s)
                 request = deploy_v1.GetReleaseRequest(
@@ -1509,7 +1569,7 @@ class CloudDeployAsyncClient:
                 )
 
                 # Make the request
-                response = client.get_release(request=request)
+                response = await client.get_release(request=request)
 
                 # Handle the response
                 print(response)
@@ -1579,7 +1639,12 @@ class CloudDeployAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1598,14 +1663,13 @@ class CloudDeployAsyncClient:
         r"""Creates a new Release in a given project and
         location.
 
-
         .. code-block:: python
 
             from google.cloud import deploy_v1
 
-            def sample_create_release():
+            async def sample_create_release():
                 # Create a client
-                client = deploy_v1.CloudDeployClient()
+                client = deploy_v1.CloudDeployAsyncClient()
 
                 # Initialize request argument(s)
                 request = deploy_v1.CreateReleaseRequest(
@@ -1618,7 +1682,7 @@ class CloudDeployAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -1699,7 +1763,12 @@ class CloudDeployAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -1727,9 +1796,9 @@ class CloudDeployAsyncClient:
 
             from google.cloud import deploy_v1
 
-            def sample_approve_rollout():
+            async def sample_approve_rollout():
                 # Create a client
-                client = deploy_v1.CloudDeployClient()
+                client = deploy_v1.CloudDeployAsyncClient()
 
                 # Initialize request argument(s)
                 request = deploy_v1.ApproveRolloutRequest(
@@ -1738,7 +1807,7 @@ class CloudDeployAsyncClient:
                 )
 
                 # Make the request
-                response = client.approve_rollout(request=request)
+                response = await client.approve_rollout(request=request)
 
                 # Handle the response
                 print(response)
@@ -1798,7 +1867,12 @@ class CloudDeployAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1818,9 +1892,9 @@ class CloudDeployAsyncClient:
 
             from google.cloud import deploy_v1
 
-            def sample_list_rollouts():
+            async def sample_list_rollouts():
                 # Create a client
-                client = deploy_v1.CloudDeployClient()
+                client = deploy_v1.CloudDeployAsyncClient()
 
                 # Initialize request argument(s)
                 request = deploy_v1.ListRolloutsRequest(
@@ -1831,7 +1905,7 @@ class CloudDeployAsyncClient:
                 page_result = client.list_rollouts(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -1901,12 +1975,20 @@ class CloudDeployAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListRolloutsAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -1927,9 +2009,9 @@ class CloudDeployAsyncClient:
 
             from google.cloud import deploy_v1
 
-            def sample_get_rollout():
+            async def sample_get_rollout():
                 # Create a client
-                client = deploy_v1.CloudDeployClient()
+                client = deploy_v1.CloudDeployAsyncClient()
 
                 # Initialize request argument(s)
                 request = deploy_v1.GetRolloutRequest(
@@ -1937,7 +2019,7 @@ class CloudDeployAsyncClient:
                 )
 
                 # Make the request
-                response = client.get_rollout(request=request)
+                response = await client.get_rollout(request=request)
 
                 # Handle the response
                 print(response)
@@ -2008,7 +2090,12 @@ class CloudDeployAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -2027,14 +2114,13 @@ class CloudDeployAsyncClient:
         r"""Creates a new Rollout in a given project and
         location.
 
-
         .. code-block:: python
 
             from google.cloud import deploy_v1
 
-            def sample_create_rollout():
+            async def sample_create_rollout():
                 # Create a client
-                client = deploy_v1.CloudDeployClient()
+                client = deploy_v1.CloudDeployAsyncClient()
 
                 # Initialize request argument(s)
                 rollout = deploy_v1.Rollout()
@@ -2051,7 +2137,7 @@ class CloudDeployAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -2132,7 +2218,12 @@ class CloudDeployAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -2160,9 +2251,9 @@ class CloudDeployAsyncClient:
 
             from google.cloud import deploy_v1
 
-            def sample_get_config():
+            async def sample_get_config():
                 # Create a client
-                client = deploy_v1.CloudDeployClient()
+                client = deploy_v1.CloudDeployAsyncClient()
 
                 # Initialize request argument(s)
                 request = deploy_v1.GetConfigRequest(
@@ -2170,7 +2261,7 @@ class CloudDeployAsyncClient:
                 )
 
                 # Make the request
-                response = client.get_config(request=request)
+                response = await client.get_config(request=request)
 
                 # Handle the response
                 print(response)
@@ -2236,7 +2327,12 @@ class CloudDeployAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -2250,7 +2346,9 @@ class CloudDeployAsyncClient:
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution("google-cloud-deploy",).version,
+        gapic_version=pkg_resources.get_distribution(
+            "google-cloud-deploy",
+        ).version,
     )
 except pkg_resources.DistributionNotFound:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
